# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [0.1.4](https://github.com/cauliyang/DeepBioP/compare/py-deepbiop-v0.1.3...py-deepbiop-v0.1.4) - 2024-08-05

### Added

- Add test_fq function
- Add ahash, anyhow, derive_builder, lexical, log
- Add deepbiop-utils crate and Python module
- Add support for processing BAM format in DeepBiop
- Add utils module and get_label_region function
- Update project versions and dependencies
- Add Rye configuration with new dev dependencies
- Add Python module with encoding functionalities
- Add new module 'deepbiop' and 'add' function

### Fixed

- Update maturin version requirement to 1.6.0
- Update Cargo.toml for edition 2021 and dependency versions

### Other

- Update version history in CHANGELOG.md
- Update changelog for version 0.1.3
- Update project URLs in pyproject.toml
- Add tests for bam and fq modules
- Update path in test_load_predict in predicts.rs
- Move fq-related Python functions to deepbiop-fq crate
- Remove unnecessary import lines
- Remove unnecessary spaces and comments
- comment out project.urls Homepage in pyproject.toml
- Add reference to rust-toolchain.toml in pyproject.toml
- Update README.md path in pyproject.toml
- Update location of README.md file
- Remove README.md
- Update release-python.yml and pyproject.toml
- Update project versions and dependencies
- Add initial changelog documentation
- add docs template
- Remove unnecessary relative import in Cargo.toml
- add lock file
- add fastq module

## [0.1.3](https://github.com/cauliyang/DeepBioP/releases/tag/py-deepbiop-v0.1.3) - 2024-08-05

### Added

- Add test_fq function
- Add ahash, anyhow, derive_builder, lexical, log
- Add deepbiop-utils crate and Python module
- Add support for processing BAM format in DeepBiop
- Add utils module and get_label_region function
- Update project versions and dependencies
- Add Rye configuration with new dev dependencies
- Add Python module with encoding functionalities
- Add new module 'deepbiop' and 'add' function

### Fixed

- Update maturin version requirement to 1.6.0
- Update Cargo.toml for edition 2021 and dependency versions

### Other

- Update project URLs in pyproject.toml
- Add tests for bam and fq modules
- Update path in test_load_predict in predicts.rs
- Move fq-related Python functions to deepbiop-fq crate
- Remove unnecessary import lines
- Remove unnecessary spaces and comments
- comment out project.urls Homepage in pyproject.toml
- Add reference to rust-toolchain.toml in pyproject.toml
- Update README.md path in pyproject.toml
- Update location of README.md file
- Remove README.md
- Update release-python.yml and pyproject.toml
- Update project versions and dependencies
- Add initial changelog documentation
- add docs template
- Remove unnecessary relative import in Cargo.toml
- add lock file
- add fastq module

## \[Unreleased\]

## [0.1.0](https://github.com/cauliyang/DeepBioP/releases/tag/py-deepbiop-v0.1.0) - 2024-08-03

### Added

- Add Rye configuration with new dev dependencies
- Add Python module with encoding functionalities
- Add new module 'deepbiop' and 'add' function

### Fixed

- Update Cargo.toml for edition 2021 and dependency versions

### Other

- Add initial changelog documentation
- add docs template
- Remove unnecessary relative import in Cargo.toml
- add lock file
- add fastq module

### Added

- Add Rye configuration with new dev dependencies
- Add Python module with encoding functionalities
- Add new module 'deepbiop' and 'add' function

### Fixed

- Update Cargo.toml for edition 2021 and dependency versions

### Other

- add docs template
- Remove unnecessary relative import in Cargo.toml
- add lock file
- add fastq module
